swh-scanner
===========

Source code scanner to analyze code bases and compare them with source code
artifacts archived by Software Heritage

See the
[documentation](https://docs.softwareheritage.org/devel/swh-scanner/index.html)
for more details.